@@ -39,8 +39,7 @@ import qualified Distribution.CabalSpecVersion as C
 import qualified Distribution.FieldGrammar     as C
 import qualified Distribution.Fields           as C
 import qualified Distribution.Parsec           as C
-import qualified Distribution.Parsec.Newtypes  as C
-import qualified Distribution.Simple.Utils     as C
+import qualified Distribution.Utils.Generic    as C
 
 import Cabal.Internal.Newtypes
 import Cabal.Parse
@@ -53,7 +52,7 @@ infixl 1 <&>
 -- Read config
 -------------------------------------------------------------------------------
 
--- | High level convinience function to find and read @~\/.cabal\/config@ file
+-- | High level convenience function to find and read @~\/.cabal\/config@ file
 --
 -- May throw 'IOException' when file doesn't exist, and 'ParseError'
 -- on parse error.
@@ -75,8 +74,14 @@ findConfig = do
     case env of
         Just p -> return p
         Nothing -> do
-            c <- getAppUserDataDirectory "cabal"
-            return (c </> "config")
+            cabalDir <- findCabalDir
+            return (cabalDir </> "config")
+
+-- | Find the @~\/.cabal@ dir.
+findCabalDir :: IO FilePath
+findCabalDir = do
+    cabalDirVar <- lookupEnv "CABAL_DIR"
+    maybe (getAppUserDataDirectory "cabal") return cabalDirVar
 
 -------------------------------------------------------------------------------
 -- Config
@@ -174,7 +179,7 @@ repoGrammar = Repo
 -- | Fill the default in @~\/.cabal\/config@  file.
 resolveConfig :: Config Maybe -> IO (Config Identity)
 resolveConfig cfg = do
-    c <- getAppUserDataDirectory "cabal"
+    c <- findCabalDir
     return cfg
         { cfgRemoteRepoCache = Identity $ fromMaybe (c </> "packages") (cfgRemoteRepoCache cfg)
         , cfgInstallDir      = Identity $ fromMaybe (c </> "bin")      (cfgInstallDir cfg)
